# -*- coding: utf-8 -*-

from .bar import CoopBar

urlpatterns = []

bar = CoopBar()  # This is a Borg
